@@ -30,7 +30,7 @@
 /* 64 ABI */
 #define __SCMP_NR_BASE	5000
 
-/* NOTE: based on Linux 4.15-rc7 */
+/* NOTE: based on Linux v5.4-rc4 */
 const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "_llseek", __PNR__llseek },
 	{ "_newselect", (__SCMP_NR_BASE + 22) },
@@ -62,11 +62,17 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "chown32", __PNR_chown32 },
 	{ "chroot", (__SCMP_NR_BASE + 156) },
 	{ "clock_adjtime", (__SCMP_NR_BASE + 300) },
+	{ "clock_adjtime64", __PNR_clock_adjtime64 },
 	{ "clock_getres", (__SCMP_NR_BASE + 223) },
+	{ "clock_getres_time64", __PNR_clock_getres_time64 },
 	{ "clock_gettime", (__SCMP_NR_BASE + 222) },
+	{ "clock_gettime64", __PNR_clock_gettime64 },
 	{ "clock_nanosleep", (__SCMP_NR_BASE + 224) },
+	{ "clock_nanosleep_time64", __PNR_clock_nanosleep_time64 },
 	{ "clock_settime", (__SCMP_NR_BASE + 221) },
+	{ "clock_settime64", __PNR_clock_settime64 },
 	{ "clone", (__SCMP_NR_BASE + 55) },
+	{ "clone3", (__SCMP_NR_BASE + 435) },
 	{ "close", (__SCMP_NR_BASE + 3) },
 	{ "connect", (__SCMP_NR_BASE + 41) },
 	{ "copy_file_range", (__SCMP_NR_BASE + 320) },
@@ -110,7 +116,11 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "flock", (__SCMP_NR_BASE + 71) },
 	{ "fork", (__SCMP_NR_BASE + 56) },
 	{ "fremovexattr", (__SCMP_NR_BASE + 191) },
+	{ "fsconfig", (__SCMP_NR_BASE + 431) },
 	{ "fsetxattr", (__SCMP_NR_BASE + 182) },
+	{ "fsmount", (__SCMP_NR_BASE + 432) },
+	{ "fsopen", (__SCMP_NR_BASE + 430) },
+	{ "fspick", (__SCMP_NR_BASE + 433) },
 	{ "fstat", (__SCMP_NR_BASE + 5) },
 	{ "fstat64", __PNR_fstat64 },
 	{ "fstatat64", __PNR_fstat64 },
@@ -121,6 +131,7 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "ftruncate", (__SCMP_NR_BASE + 75) },
 	{ "ftruncate64", __PNR_ftruncate64 },
 	{ "futex", (__SCMP_NR_BASE + 194) },
+	{ "futex_time64", __PNR_futex_time64 },
 	{ "futimesat", (__SCMP_NR_BASE + 251) },
 	{ "get_kernel_syms", (__SCMP_NR_BASE + 170) },
 	{ "get_mempolicy", (__SCMP_NR_BASE + 228) },
@@ -173,8 +184,12 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "io_destroy", (__SCMP_NR_BASE + 201) },
 	{ "io_getevents", (__SCMP_NR_BASE + 202) },
 	{ "io_pgetevents", (__SCMP_NR_BASE + 328) },
+	{ "io_pgetevents_time64", __PNR_io_pgetevents_time64 },
 	{ "io_setup", (__SCMP_NR_BASE + 200) },
 	{ "io_submit", (__SCMP_NR_BASE + 203) },
+	{ "io_uring_setup", (__SCMP_NR_BASE + 425) },
+	{ "io_uring_enter", (__SCMP_NR_BASE + 426) },
+	{ "io_uring_register", (__SCMP_NR_BASE + 427) },
 	{ "ioctl", (__SCMP_NR_BASE + 15) },
 	{ "ioperm", __PNR_ioperm },
 	{ "iopl", __PNR_iopl },
@@ -218,6 +233,7 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "mmap2", __PNR_mmap2 },
 	{ "modify_ldt", __PNR_modify_ldt },
 	{ "mount", (__SCMP_NR_BASE + 160) },
+	{ "move_mount", (__SCMP_NR_BASE + 429) },
 	{ "move_pages", (__SCMP_NR_BASE + 267) },
 	{ "mprotect", (__SCMP_NR_BASE + 10) },
 	{ "mpx", __PNR_mpx },
@@ -225,7 +241,9 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "mq_notify", (__SCMP_NR_BASE + 234) },
 	{ "mq_open", (__SCMP_NR_BASE + 230) },
 	{ "mq_timedreceive", (__SCMP_NR_BASE + 233) },
+	{ "mq_timedreceive_time64", __PNR_mq_timedreceive_time64 },
 	{ "mq_timedsend", (__SCMP_NR_BASE + 232) },
+	{ "mq_timedsend_time64", __PNR_mq_timedsend_time64 },
 	{ "mq_unlink", (__SCMP_NR_BASE + 231) },
 	{ "mremap", (__SCMP_NR_BASE + 24) },
 	{ "msgctl", (__SCMP_NR_BASE + 69) },
@@ -250,6 +268,7 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "oldwait4", __PNR_oldwait4 },
 	{ "open", (__SCMP_NR_BASE + 2) },
 	{ "open_by_handle_at", (__SCMP_NR_BASE + 299) },
+	{ "open_tree", (__SCMP_NR_BASE + 428) },
 	{ "openat", (__SCMP_NR_BASE + 247) },
 	{ "pause", (__SCMP_NR_BASE + 33) },
 	{ "pciconfig_iobase", __PNR_pciconfig_iobase },
@@ -257,6 +276,8 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "pciconfig_write", __PNR_pciconfig_write },
 	{ "perf_event_open", (__SCMP_NR_BASE + 292) },
 	{ "personality", (__SCMP_NR_BASE + 132) },
+	{ "pidfd_open", (__SCMP_NR_BASE + 434) },
+	{ "pidfd_send_signal", (__SCMP_NR_BASE + 424) },
 	{ "pipe", (__SCMP_NR_BASE + 21) },
 	{ "pipe2", (__SCMP_NR_BASE + 287) },
 	{ "pivot_root", (__SCMP_NR_BASE + 151) },
@@ -265,6 +286,7 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "pkey_mprotect", (__SCMP_NR_BASE + 323) },
 	{ "poll", (__SCMP_NR_BASE + 7) },
 	{ "ppoll", (__SCMP_NR_BASE + 261) },
+	{ "ppoll_time64", __PNR_ppoll_time64 },
 	{ "prctl", (__SCMP_NR_BASE + 153) },
 	{ "pread64", (__SCMP_NR_BASE + 16) },
 	{ "preadv", (__SCMP_NR_BASE + 289) },
@@ -275,6 +297,7 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "prof", __PNR_prof },
 	{ "profil", __PNR_profil },
 	{ "pselect6", (__SCMP_NR_BASE + 260) },
+	{ "pselect6_time64", __PNR_pselect6_time64 },
 	{ "ptrace", (__SCMP_NR_BASE + 99) },
 	{ "putpmsg", (__SCMP_NR_BASE + 175) },
 	{ "pwrite64", (__SCMP_NR_BASE + 17) },
@@ -292,6 +315,7 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "recv", __PNR_recv },
 	{ "recvfrom", (__SCMP_NR_BASE + 44) },
 	{ "recvmmsg", (__SCMP_NR_BASE + 294) },
+	{ "recvmmsg_time64", __PNR_recvmmsg_time64 },
 	{ "recvmsg", (__SCMP_NR_BASE + 46) },
 	{ "remap_file_pages", (__SCMP_NR_BASE + 210) },
 	{ "removexattr", (__SCMP_NR_BASE + 189) },
@@ -309,6 +333,7 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "rt_sigreturn", (__SCMP_NR_BASE + 211) },
 	{ "rt_sigsuspend", (__SCMP_NR_BASE + 128) },
 	{ "rt_sigtimedwait", (__SCMP_NR_BASE + 126) },
+	{ "rt_sigtimedwait_time64", __PNR_rt_sigtimedwait_time64 },
 	{ "rt_tgsigqueueinfo", (__SCMP_NR_BASE + 291) },
 	{ "rtas", __PNR_rtas },
 	{ "s390_guarded_storage", __PNR_s390_guarded_storage },
@@ -323,6 +348,7 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "sched_getparam", (__SCMP_NR_BASE + 140) },
 	{ "sched_getscheduler", (__SCMP_NR_BASE + 142) },
 	{ "sched_rr_get_interval", (__SCMP_NR_BASE + 145) },
+	{ "sched_rr_get_interval_time64", __PNR_sched_rr_get_interval_time64 },
 	{ "sched_setaffinity", (__SCMP_NR_BASE + 195) },
 	{ "sched_setattr", (__SCMP_NR_BASE + 309) },
 	{ "sched_setparam", (__SCMP_NR_BASE + 139) },
@@ -335,6 +361,7 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "semget", (__SCMP_NR_BASE + 62) },
 	{ "semop", (__SCMP_NR_BASE + 63) },
 	{ "semtimedop", (__SCMP_NR_BASE + 214) },
+	{ "semtimedop_time64", __PNR_semtimedop_time64 },
 	{ "send", __PNR_send },
 	{ "sendfile", (__SCMP_NR_BASE + 39) },
 	{ "sendfile64", __PNR_sendfile64 },
@@ -428,11 +455,15 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "timer_delete", (__SCMP_NR_BASE + 220) },
 	{ "timer_getoverrun", (__SCMP_NR_BASE + 219) },
 	{ "timer_gettime", (__SCMP_NR_BASE + 218) },
+	{ "timer_gettime64", __PNR_timer_gettime64 },
 	{ "timer_settime", (__SCMP_NR_BASE + 217) },
+	{ "timer_settime64", __PNR_timer_settime64 },
 	{ "timerfd", (__SCMP_NR_BASE + 277) },
 	{ "timerfd_create", (__SCMP_NR_BASE + 280) },
 	{ "timerfd_gettime", (__SCMP_NR_BASE + 281) },
+	{ "timerfd_gettime64", __PNR_timerfd_gettime64 },
 	{ "timerfd_settime", (__SCMP_NR_BASE + 282) },
+	{ "timerfd_settime64", __PNR_timerfd_settime64 },
 	{ "times", (__SCMP_NR_BASE + 98) },
 	{ "tkill", (__SCMP_NR_BASE + 192) },
 	{ "truncate", (__SCMP_NR_BASE + 74) },
@@ -454,6 +485,7 @@ const struct arch_syscall_def mips64_syscall_table[] = { \
 	{ "ustat", (__SCMP_NR_BASE + 133) },
 	{ "utime", (__SCMP_NR_BASE + 130) },
 	{ "utimensat", (__SCMP_NR_BASE + 275) },
+	{ "utimensat_time64", __PNR_utimensat_time64 },
 	{ "utimes", (__SCMP_NR_BASE + 226) },
 	{ "vfork", __PNR_vfork },
 	{ "vhangup", (__SCMP_NR_BASE + 150) },
