@@ -30,7 +30,7 @@
 /* N32 ABI */
 #define __SCMP_NR_BASE	6000
 
-/* NOTE: based on Linux 4.9 */
+/* NOTE: based on Linux v5.4-rc4 */
 const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "_llseek", __PNR__llseek },
 	{ "_newselect", (__SCMP_NR_BASE + 22) },
@@ -62,11 +62,17 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "chown32", __PNR_chown32 },
 	{ "chroot", (__SCMP_NR_BASE + 156) },
 	{ "clock_adjtime", (__SCMP_NR_BASE + 305) },
+	{ "clock_adjtime64", (__SCMP_NR_BASE + 405) },
 	{ "clock_getres", (__SCMP_NR_BASE + 227) },
+	{ "clock_getres_time64", (__SCMP_NR_BASE + 406) },
 	{ "clock_gettime", (__SCMP_NR_BASE + 226) },
+	{ "clock_gettime64", (__SCMP_NR_BASE + 403) },
 	{ "clock_nanosleep", (__SCMP_NR_BASE + 228) },
+	{ "clock_nanosleep_time64", (__SCMP_NR_BASE + 407) },
 	{ "clock_settime", (__SCMP_NR_BASE + 225) },
+	{ "clock_settime64", (__SCMP_NR_BASE + 404) },
 	{ "clone", (__SCMP_NR_BASE + 55) },
+	{ "clone3", (__SCMP_NR_BASE + 435) },
 	{ "close", (__SCMP_NR_BASE + 3) },
 	{ "connect", (__SCMP_NR_BASE + 41) },
 	{ "copy_file_range", (__SCMP_NR_BASE + 324) },
@@ -110,7 +116,11 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "flock", (__SCMP_NR_BASE + 71) },
 	{ "fork", (__SCMP_NR_BASE + 56) },
 	{ "fremovexattr", (__SCMP_NR_BASE + 191) },
+	{ "fsconfig", (__SCMP_NR_BASE + 431) },
 	{ "fsetxattr", (__SCMP_NR_BASE + 182) },
+	{ "fsmount", (__SCMP_NR_BASE + 432) },
+	{ "fsopen", (__SCMP_NR_BASE + 430) },
+	{ "fspick", (__SCMP_NR_BASE + 433) },
 	{ "fstat", (__SCMP_NR_BASE + 5) },
 	{ "fstat64", __PNR_fstat64 },
 	{ "fstatat64", __PNR_fstat64 },
@@ -121,11 +131,13 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "ftruncate", (__SCMP_NR_BASE + 75) },
 	{ "ftruncate64", __PNR_ftruncate64 },
 	{ "futex", (__SCMP_NR_BASE + 194) },
+	{ "futex_time64", (__SCMP_NR_BASE + 422) },
 	{ "futimesat", (__SCMP_NR_BASE + 255) },
 	{ "get_kernel_syms", (__SCMP_NR_BASE + 170) },
 	{ "get_mempolicy", (__SCMP_NR_BASE + 232) },
 	{ "get_robust_list", (__SCMP_NR_BASE + 273) },
 	{ "get_thread_area", __PNR_get_thread_area },
+	{ "get_tls", __PNR_get_tls },
 	{ "getcpu", (__SCMP_NR_BASE + 275) },
 	{ "getcwd", (__SCMP_NR_BASE + 77) },
 	{ "getdents", (__SCMP_NR_BASE + 76) },
@@ -171,8 +183,13 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "io_cancel", (__SCMP_NR_BASE + 204) },
 	{ "io_destroy", (__SCMP_NR_BASE + 201) },
 	{ "io_getevents", (__SCMP_NR_BASE + 202) },
+	{ "io_pgetevents", (__SCMP_NR_BASE + 332) },
+	{ "io_pgetevents_time64", (__SCMP_NR_BASE + 416) },
 	{ "io_setup", (__SCMP_NR_BASE + 200) },
 	{ "io_submit", (__SCMP_NR_BASE + 203) },
+	{ "io_uring_setup", (__SCMP_NR_BASE + 425) },
+	{ "io_uring_enter", (__SCMP_NR_BASE + 426) },
+	{ "io_uring_register", (__SCMP_NR_BASE + 427) },
 	{ "ioctl", (__SCMP_NR_BASE + 15) },
 	{ "ioperm", __PNR_ioperm },
 	{ "iopl", __PNR_iopl },
@@ -216,6 +233,7 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "mmap2", __PNR_mmap2 },
 	{ "modify_ldt", __PNR_modify_ldt },
 	{ "mount", (__SCMP_NR_BASE + 160) },
+	{ "move_mount", (__SCMP_NR_BASE + 429) },
 	{ "move_pages", (__SCMP_NR_BASE + 271) },
 	{ "mprotect", (__SCMP_NR_BASE + 10) },
 	{ "mpx", __PNR_mpx },
@@ -223,7 +241,9 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "mq_notify", (__SCMP_NR_BASE + 238) },
 	{ "mq_open", (__SCMP_NR_BASE + 234) },
 	{ "mq_timedreceive", (__SCMP_NR_BASE + 237) },
+	{ "mq_timedreceive_time64", (__SCMP_NR_BASE + 419) },
 	{ "mq_timedsend", (__SCMP_NR_BASE + 236) },
+	{ "mq_timedsend_time64", (__SCMP_NR_BASE + 418) },
 	{ "mq_unlink", (__SCMP_NR_BASE + 235) },
 	{ "mremap", (__SCMP_NR_BASE + 24) },
 	{ "msgctl", (__SCMP_NR_BASE + 69) },
@@ -248,6 +268,7 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "oldwait4", __PNR_oldwait4 },
 	{ "open", (__SCMP_NR_BASE + 2) },
 	{ "open_by_handle_at", (__SCMP_NR_BASE + 304) },
+	{ "open_tree", (__SCMP_NR_BASE + 428) },
 	{ "openat", (__SCMP_NR_BASE + 251) },
 	{ "pause", (__SCMP_NR_BASE + 33) },
 	{ "pciconfig_iobase", __PNR_pciconfig_iobase },
@@ -255,6 +276,8 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "pciconfig_write", __PNR_pciconfig_write },
 	{ "perf_event_open", (__SCMP_NR_BASE + 296) },
 	{ "personality", (__SCMP_NR_BASE + 132) },
+	{ "pidfd_open", (__SCMP_NR_BASE + 434) },
+	{ "pidfd_send_signal", (__SCMP_NR_BASE + 424) },
 	{ "pipe", (__SCMP_NR_BASE + 21) },
 	{ "pipe2", (__SCMP_NR_BASE + 291) },
 	{ "pivot_root", (__SCMP_NR_BASE + 151) },
@@ -263,6 +286,7 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "pkey_mprotect", (__SCMP_NR_BASE + 327) },
 	{ "poll", (__SCMP_NR_BASE + 7) },
 	{ "ppoll", (__SCMP_NR_BASE + 265) },
+	{ "ppoll_time64", (__SCMP_NR_BASE + 414) },
 	{ "prctl", (__SCMP_NR_BASE + 153) },
 	{ "pread64", (__SCMP_NR_BASE + 16) },
 	{ "preadv", (__SCMP_NR_BASE + 293) },
@@ -273,6 +297,7 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "prof", __PNR_prof },
 	{ "profil", __PNR_profil },
 	{ "pselect6", (__SCMP_NR_BASE + 264) },
+	{ "pselect6_time64", (__SCMP_NR_BASE + 413) },
 	{ "ptrace", (__SCMP_NR_BASE + 99) },
 	{ "putpmsg", (__SCMP_NR_BASE + 175) },
 	{ "pwrite64", (__SCMP_NR_BASE + 17) },
@@ -290,6 +315,7 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "recv", __PNR_recv },
 	{ "recvfrom", (__SCMP_NR_BASE + 44) },
 	{ "recvmmsg", (__SCMP_NR_BASE + 298) },
+	{ "recvmmsg_time64", (__SCMP_NR_BASE + 417) },
 	{ "recvmsg", (__SCMP_NR_BASE + 46) },
 	{ "remap_file_pages", (__SCMP_NR_BASE + 210) },
 	{ "removexattr", (__SCMP_NR_BASE + 189) },
@@ -299,6 +325,7 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "request_key", (__SCMP_NR_BASE + 244) },
 	{ "restart_syscall", (__SCMP_NR_BASE + 214) },
 	{ "rmdir", (__SCMP_NR_BASE + 82) },
+	{ "rseq", (__SCMP_NR_BASE + 331) },
 	{ "rt_sigaction", (__SCMP_NR_BASE + 13) },
 	{ "rt_sigpending", (__SCMP_NR_BASE + 125) },
 	{ "rt_sigprocmask", (__SCMP_NR_BASE + 14) },
@@ -306,11 +333,14 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "rt_sigreturn", (__SCMP_NR_BASE + 211) },
 	{ "rt_sigsuspend", (__SCMP_NR_BASE + 128) },
 	{ "rt_sigtimedwait", (__SCMP_NR_BASE + 126) },
+	{ "rt_sigtimedwait_time64", (__SCMP_NR_BASE + 421) },
 	{ "rt_tgsigqueueinfo", (__SCMP_NR_BASE + 295) },
 	{ "rtas", __PNR_rtas },
+	{ "s390_guarded_storage", __PNR_s390_guarded_storage },
 	{ "s390_pci_mmio_read", __PNR_s390_pci_mmio_read },
 	{ "s390_pci_mmio_write", __PNR_s390_pci_mmio_write },
 	{ "s390_runtime_instr", __PNR_s390_runtime_instr },
+	{ "s390_sthyi", __PNR_s390_sthyi },
 	{ "sched_get_priority_max", (__SCMP_NR_BASE + 143) },
 	{ "sched_get_priority_min", (__SCMP_NR_BASE + 144) },
 	{ "sched_getaffinity", (__SCMP_NR_BASE + 196) },
@@ -318,6 +348,7 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "sched_getparam", (__SCMP_NR_BASE + 140) },
 	{ "sched_getscheduler", (__SCMP_NR_BASE + 142) },
 	{ "sched_rr_get_interval", (__SCMP_NR_BASE + 145) },
+	{ "sched_rr_get_interval_time64", (__SCMP_NR_BASE + 423) },
 	{ "sched_setaffinity", (__SCMP_NR_BASE + 195) },
 	{ "sched_setattr", (__SCMP_NR_BASE + 313) },
 	{ "sched_setparam", (__SCMP_NR_BASE + 139) },
@@ -330,6 +361,7 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "semget", (__SCMP_NR_BASE + 62) },
 	{ "semop", (__SCMP_NR_BASE + 63) },
 	{ "semtimedop", (__SCMP_NR_BASE + 215) },
+	{ "semtimedop_time64", (__SCMP_NR_BASE + 420) },
 	{ "send", __PNR_send },
 	{ "sendfile", (__SCMP_NR_BASE + 39) },
 	{ "sendfile64", (__SCMP_NR_BASE + 219) },
@@ -396,6 +428,7 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "stat64", __PNR_stat64 },
 	{ "statfs", (__SCMP_NR_BASE + 134) },
 	{ "statfs64", (__SCMP_NR_BASE + 217) },
+	{ "statx", (__SCMP_NR_BASE + 330) },
 	{ "stime", __PNR_stime },
 	{ "stty", __PNR_stty },
 	{ "subpage_prot", __PNR_subpage_prot },
@@ -422,11 +455,15 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "timer_delete", (__SCMP_NR_BASE + 224) },
 	{ "timer_getoverrun", (__SCMP_NR_BASE + 223) },
 	{ "timer_gettime", (__SCMP_NR_BASE + 222) },
+	{ "timer_gettime64", (__SCMP_NR_BASE + 408) },
 	{ "timer_settime", (__SCMP_NR_BASE + 221) },
+	{ "timer_settime64", (__SCMP_NR_BASE + 409) },
 	{ "timerfd", (__SCMP_NR_BASE + 281) },
 	{ "timerfd_create", (__SCMP_NR_BASE + 284) },
 	{ "timerfd_gettime", (__SCMP_NR_BASE + 285) },
+	{ "timerfd_gettime64", (__SCMP_NR_BASE + 410) },
 	{ "timerfd_settime", (__SCMP_NR_BASE + 286) },
+	{ "timerfd_settime64", (__SCMP_NR_BASE + 411) },
 	{ "times", (__SCMP_NR_BASE + 98) },
 	{ "tkill", (__SCMP_NR_BASE + 192) },
 	{ "truncate", (__SCMP_NR_BASE + 74) },
@@ -448,6 +485,7 @@ const struct arch_syscall_def mips64n32_syscall_table[] = { \
 	{ "ustat", (__SCMP_NR_BASE + 133) },
 	{ "utime", (__SCMP_NR_BASE + 130) },
 	{ "utimensat", (__SCMP_NR_BASE + 279) },
+	{ "utimensat_time64", (__SCMP_NR_BASE + 412) },
 	{ "utimes", (__SCMP_NR_BASE + 230) },
 	{ "vfork", __PNR_vfork },
 	{ "vhangup", (__SCMP_NR_BASE + 150) },
