@@ -10,7 +10,7 @@
 #include "arch.h"
 #include "arch-s390.h"
 
-/* NOTE: based on Linux 4.9 */
+/* NOTE: based on Linux v5.4-rc4 */
 const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "_llseek", 140 },
 	{ "_newselect", 142 },
@@ -42,11 +42,17 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "chown32", 212 },
 	{ "chroot", 61 },
 	{ "clock_adjtime", 337 },
+	{ "clock_adjtime64", 405 },
 	{ "clock_getres", 261 },
+	{ "clock_getres_time64", 406 },
 	{ "clock_gettime", 260 },
+	{ "clock_gettime64", 403 },
 	{ "clock_nanosleep", 262 },
+	{ "clock_nanosleep_time64", 407 },
 	{ "clock_settime", 259 },
+	{ "clock_settime64", 404 },
 	{ "clone", 120 },
+	{ "clone3", 435 },
 	{ "close", 6 },
 	{ "connect", 362 },
 	{ "copy_file_range", 375 },
@@ -90,7 +96,11 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "flock", 143 },
 	{ "fork", 2 },
 	{ "fremovexattr", 235 },
+	{ "fsconfig", 431 },
 	{ "fsetxattr", 226 },
+	{ "fsmount", 432 },
+	{ "fsopen", 430 },
+	{ "fspick", 433 },
 	{ "fstat", 108 },
 	{ "fstat64", 197 },
 	{ "fstatat64", 293 },
@@ -101,11 +111,13 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "ftruncate", 93 },
 	{ "ftruncate64", 194 },
 	{ "futex", 238 },
+	{ "futex_time64", 422 },
 	{ "futimesat", 292 },
 	{ "get_kernel_syms", 130 },
 	{ "get_mempolicy", 269 },
 	{ "get_robust_list", 305 },
 	{ "get_thread_area", __PNR_get_thread_area },
+	{ "get_tls", __PNR_get_tls },
 	{ "getcpu", 311 },
 	{ "getcwd", 183 },
 	{ "getdents", 141 },
@@ -151,8 +163,13 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "io_cancel", 247 },
 	{ "io_destroy", 244 },
 	{ "io_getevents", 245 },
+	{ "io_pgetevents", 382 },
+	{ "io_pgetevents_time64", 416 },
 	{ "io_setup", 243 },
 	{ "io_submit", 246 },
+	{ "io_uring_setup", 425 },
+	{ "io_uring_enter", 426 },
+	{ "io_uring_register", 427 },
 	{ "ioctl", 54 },
 	{ "ioperm", 101 },
 	{ "iopl", __PNR_iopl },
@@ -160,7 +177,7 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "ioprio_set", 282 },
 	{ "ipc", 117 },
 	{ "kcmp", 343 },
-	{ "kexec_file_load", __PNR_kexec_file_load },
+	{ "kexec_file_load", 381 },
 	{ "kexec_load", 277 },
 	{ "keyctl", 280 },
 	{ "kill", 37 },
@@ -196,6 +213,7 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "mmap2", 192 },
 	{ "modify_ldt", __PNR_modify_ldt },
 	{ "mount", 21 },
+	{ "move_mount", 429 },
 	{ "move_pages", 310 },
 	{ "mprotect", 125 },
 	{ "mpx", __PNR_mpx },
@@ -203,13 +221,15 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "mq_notify", 275 },
 	{ "mq_open", 271 },
 	{ "mq_timedreceive", 274 },
+	{ "mq_timedreceive_time64", 419 },
 	{ "mq_timedsend", 273 },
+	{ "mq_timedsend_time64", 418 },
 	{ "mq_unlink", 272 },
 	{ "mremap", 163 },
-	{ "msgctl", __PNR_msgctl },
-	{ "msgget", __PNR_msgget },
-	{ "msgrcv", __PNR_msgrcv },
-	{ "msgsnd", __PNR_msgsnd },
+	{ "msgctl", 402 },
+	{ "msgget", 399 },
+	{ "msgrcv", 401 },
+	{ "msgsnd", 400 },
 	{ "msync", 144 },
 	{ "multiplexer", __PNR_multiplexer },
 	{ "munlock", 151 },
@@ -228,6 +248,7 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "oldwait4", __PNR_oldwait4 },
 	{ "open", 5 },
 	{ "open_by_handle_at", 336 },
+	{ "open_tree", 428 },
 	{ "openat", 288 },
 	{ "pause", 29 },
 	{ "pciconfig_iobase", __PNR_pciconfig_iobase },
@@ -235,14 +256,17 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "pciconfig_write", __PNR_pciconfig_write },
 	{ "perf_event_open", 331 },
 	{ "personality", 136 },
+	{ "pidfd_open", 434 },
+	{ "pidfd_send_signal", 424 },
 	{ "pipe", 42 },
 	{ "pipe2", 325 },
 	{ "pivot_root", 217 },
-	{ "pkey_alloc", __PNR_pkey_alloc },
-	{ "pkey_free", __PNR_pkey_free },
-	{ "pkey_mprotect", __PNR_pkey_mprotect },
+	{ "pkey_alloc", 385 },
+	{ "pkey_free", 386 },
+	{ "pkey_mprotect", 384 },
 	{ "poll", 168 },
 	{ "ppoll", 302 },
+	{ "ppoll_time64", 414 },
 	{ "prctl", 172 },
 	{ "pread64", 180 },
 	{ "preadv", 328 },
@@ -253,6 +277,7 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "prof", __PNR_prof },
 	{ "profil", __PNR_profil },
 	{ "pselect6", 301 },
+	{ "pselect6_time64", 413 },
 	{ "ptrace", 26 },
 	{ "putpmsg", 189 },
 	{ "pwrite64", 181 },
@@ -270,6 +295,7 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "recv", __PNR_recv },
 	{ "recvfrom", 371 },
 	{ "recvmmsg", 357 },
+	{ "recvmmsg_time64", 417 },
 	{ "recvmsg", 372 },
 	{ "remap_file_pages", 267 },
 	{ "removexattr", 233 },
@@ -279,6 +305,7 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "request_key", 279 },
 	{ "restart_syscall", 7 },
 	{ "rmdir", 40 },
+	{ "rseq", 383 },
 	{ "rt_sigaction", 174 },
 	{ "rt_sigpending", 176 },
 	{ "rt_sigprocmask", 175 },
@@ -286,11 +313,14 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "rt_sigreturn", 173 },
 	{ "rt_sigsuspend", 179 },
 	{ "rt_sigtimedwait", 177 },
+	{ "rt_sigtimedwait_time64", 421 },
 	{ "rt_tgsigqueueinfo", 330 },
 	{ "rtas", __PNR_rtas },
+	{ "s390_guarded_storage", 378 },
 	{ "s390_pci_mmio_read", 353 },
 	{ "s390_pci_mmio_write", 352 },
 	{ "s390_runtime_instr", 342 },
+	{ "s390_sthyi", 380 },
 	{ "sched_get_priority_max", 159 },
 	{ "sched_get_priority_min", 160 },
 	{ "sched_getaffinity", 240 },
@@ -298,6 +328,7 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "sched_getparam", 155 },
 	{ "sched_getscheduler", 157 },
 	{ "sched_rr_get_interval", 161 },
+	{ "sched_rr_get_interval_time64", 423 },
 	{ "sched_setaffinity", 239 },
 	{ "sched_setattr", 345 },
 	{ "sched_setparam", 154 },
@@ -306,10 +337,11 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "seccomp", 348 },
 	{ "security", __PNR_security },
 	{ "select", __PNR_select },
-	{ "semctl", __PNR_semctl },
-	{ "semget", __PNR_semget },
+	{ "semctl", 394 },
+	{ "semget", 393 },
 	{ "semop", __PNR_semop },
 	{ "semtimedop", __PNR_semtimedop },
+	{ "semtimedop_time64", 420 },
 	{ "send", __PNR_send },
 	{ "sendfile", 187 },
 	{ "sendfile64", 223 },
@@ -351,10 +383,10 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "setuid32", 213 },
 	{ "setxattr", 224 },
 	{ "sgetmask", __PNR_sgetmask },
-	{ "shmat", __PNR_shmat },
-	{ "shmctl", __PNR_shmctl },
-	{ "shmdt", __PNR_shmdt },
-	{ "shmget", __PNR_shmget },
+	{ "shmat", 397 },
+	{ "shmctl", 396 },
+	{ "shmdt", 398 },
+	{ "shmget", 395 },
 	{ "shutdown", 373 },
 	{ "sigaction", 67 },
 	{ "sigaltstack", 186 },
@@ -376,6 +408,7 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "stat64", 195 },
 	{ "statfs", 99 },
 	{ "statfs64", 265 },
+	{ "statx", 379 },
 	{ "stime", 25 },
 	{ "stty", __PNR_stty },
 	{ "subpage_prot", __PNR_subpage_prot },
@@ -402,11 +435,15 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "timer_delete", 258 },
 	{ "timer_getoverrun", 257 },
 	{ "timer_gettime", 256 },
+	{ "timer_gettime64", 408 },
 	{ "timer_settime", 255 },
+	{ "timer_settime64", 409 },
 	{ "timerfd", 317 },
 	{ "timerfd_create", 319 },
 	{ "timerfd_gettime", 321 },
+	{ "timerfd_gettime64", 410 },
 	{ "timerfd_settime", 320 },
+	{ "timerfd_settime64", 411 },
 	{ "times", 43 },
 	{ "tkill", 237 },
 	{ "truncate", 92 },
@@ -428,6 +465,7 @@ const struct arch_syscall_def s390_syscall_table[] = { \
 	{ "ustat", 62 },
 	{ "utime", 30 },
 	{ "utimensat", 315 },
+	{ "utimensat_time64", 412 },
 	{ "utimes", 313 },
 	{ "vfork", 190 },
 	{ "vhangup", 111 },
@@ -493,6 +531,14 @@ int s390_syscall_resolve_name(const char *name)
 		return __PNR_sendto;
 	else if (strcmp(name, "setsockopt") == 0)
 		return __PNR_setsockopt;
+	else if (strcmp(name, "shmat") == 0)
+		return __PNR_shmat;
+	else if (strcmp(name, "shmdt") == 0)
+		return __PNR_shmdt;
+	else if (strcmp(name, "shmget") == 0)
+		return __PNR_shmget;
+	else if (strcmp(name, "shmctl") == 0)
+		return __PNR_shmctl;
 	else if (strcmp(name, "shutdown") == 0)
 		return __PNR_shutdown;
 	else if (strcmp(name, "socket") == 0)
@@ -558,6 +604,14 @@ const char *s390_syscall_resolve_num(int num)
 		return "sendto";
 	else if (num == __PNR_setsockopt)
 		return "setsockopt";
+	else if (num == __PNR_shmat)
+		return "shmat";
+	else if (num == __PNR_shmdt)
+		return "shmdt";
+	else if (num == __PNR_shmget)
+		return "shmget";
+	else if (num == __PNR_shmctl)
+		return "shmctl";
 	else if (num == __PNR_shutdown)
 		return "shutdown";
 	else if (num == __PNR_socket)
