@@ -26,7 +26,7 @@
 #include "arch.h"
 #include "arch-x32.h"
 
-/* NOTE: based on Linux 4.15-rc7 */
+/* NOTE: based on Linux v5.4-rc4 */
 const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "_llseek", __PNR__llseek },
 	{ "_newselect", __PNR__newselect },
@@ -58,11 +58,17 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "chown32", __PNR_chown32 },
 	{ "chroot", (X32_SYSCALL_BIT + 161) },
 	{ "clock_adjtime", (X32_SYSCALL_BIT + 305) },
+	{ "clock_adjtime64", __PNR_clock_adjtime64 },
 	{ "clock_getres", (X32_SYSCALL_BIT + 229) },
+	{ "clock_getres_time64", __PNR_clock_getres_time64 },
 	{ "clock_gettime", (X32_SYSCALL_BIT + 228) },
+	{ "clock_gettime64", __PNR_clock_gettime64 },
 	{ "clock_nanosleep", (X32_SYSCALL_BIT + 230) },
+	{ "clock_nanosleep_time64", __PNR_clock_nanosleep_time64 },
 	{ "clock_settime", (X32_SYSCALL_BIT + 227) },
+	{ "clock_settime64", __PNR_clock_settime64 },
 	{ "clone", (X32_SYSCALL_BIT + 56) },
+	{ "clone3", (X32_SYSCALL_BIT + 435) },
 	{ "close", (X32_SYSCALL_BIT + 3) },
 	{ "connect", (X32_SYSCALL_BIT + 42) },
 	{ "copy_file_range", (X32_SYSCALL_BIT + 326) },
@@ -106,7 +112,11 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "flock", (X32_SYSCALL_BIT + 73) },
 	{ "fork", (X32_SYSCALL_BIT + 57) },
 	{ "fremovexattr", (X32_SYSCALL_BIT + 199) },
+	{ "fsconfig", (X32_SYSCALL_BIT + 431) },
 	{ "fsetxattr", (X32_SYSCALL_BIT + 190) },
+	{ "fsmount", (X32_SYSCALL_BIT + 432) },
+	{ "fsopen", (X32_SYSCALL_BIT + 430) },
+	{ "fspick", (X32_SYSCALL_BIT + 433) },
 	{ "fstat", (X32_SYSCALL_BIT + 5) },
 	{ "fstat64", __PNR_fstat64 },
 	{ "fstatat64", __PNR_fstatat64 },
@@ -117,6 +127,7 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "ftruncate", (X32_SYSCALL_BIT + 77) },
 	{ "ftruncate64", __PNR_ftruncate64 },
 	{ "futex", (X32_SYSCALL_BIT + 202) },
+	{ "futex_time64", __PNR_futex_time64 },
 	{ "futimesat", (X32_SYSCALL_BIT + 261) },
 	{ "get_kernel_syms", __PNR_get_kernel_syms },
 	{ "get_mempolicy", (X32_SYSCALL_BIT + 239) },
@@ -169,8 +180,12 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "io_destroy", (X32_SYSCALL_BIT + 207) },
 	{ "io_getevents", (X32_SYSCALL_BIT + 208) },
 	{ "io_pgetevents", (X32_SYSCALL_BIT + 333) },
+	{ "io_pgetevents_time64", __PNR_io_pgetevents_time64 },
 	{ "io_setup", (X32_SYSCALL_BIT + 543) },
 	{ "io_submit", (X32_SYSCALL_BIT + 544) },
+	{ "io_uring_setup", (X32_SYSCALL_BIT + 425) },
+	{ "io_uring_enter", (X32_SYSCALL_BIT + 426) },
+	{ "io_uring_register", (X32_SYSCALL_BIT + 427) },
 	{ "ioctl", (X32_SYSCALL_BIT + 514) },
 	{ "ioperm", (X32_SYSCALL_BIT + 173) },
 	{ "iopl", (X32_SYSCALL_BIT + 172) },
@@ -214,6 +229,7 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "mmap2", __PNR_mmap2 },
 	{ "modify_ldt", (X32_SYSCALL_BIT + 154) },
 	{ "mount", (X32_SYSCALL_BIT + 165) },
+	{ "move_mount", (X32_SYSCALL_BIT + 429) },
 	{ "move_pages", (X32_SYSCALL_BIT + 533) },
 	{ "mprotect", (X32_SYSCALL_BIT + 10) },
 	{ "mpx", __PNR_mpx },
@@ -221,7 +237,9 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "mq_notify", (X32_SYSCALL_BIT + 527) },
 	{ "mq_open", (X32_SYSCALL_BIT + 240) },
 	{ "mq_timedreceive", (X32_SYSCALL_BIT + 243) },
+	{ "mq_timedreceive_time64", __PNR_mq_timedreceive_time64 },
 	{ "mq_timedsend", (X32_SYSCALL_BIT + 242) },
+	{ "mq_timedsend_time64", __PNR_mq_timedsend_time64 },
 	{ "mq_unlink", (X32_SYSCALL_BIT + 241) },
 	{ "mremap", (X32_SYSCALL_BIT + 25) },
 	{ "msgctl", (X32_SYSCALL_BIT + 71) },
@@ -246,6 +264,7 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "oldwait4", __PNR_oldwait4 },
 	{ "open", (X32_SYSCALL_BIT + 2) },
 	{ "open_by_handle_at", (X32_SYSCALL_BIT + 304) },
+	{ "open_tree", (X32_SYSCALL_BIT + 428) },
 	{ "openat", (X32_SYSCALL_BIT + 257) },
 	{ "pause", (X32_SYSCALL_BIT + 34) },
 	{ "pciconfig_iobase", __PNR_pciconfig_iobase },
@@ -253,6 +272,8 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "pciconfig_write", __PNR_pciconfig_write },
 	{ "perf_event_open", (X32_SYSCALL_BIT + 298) },
 	{ "personality", (X32_SYSCALL_BIT + 135) },
+	{ "pidfd_open", (X32_SYSCALL_BIT + 434) },
+	{ "pidfd_send_signal", (X32_SYSCALL_BIT + 424) },
 	{ "pipe", (X32_SYSCALL_BIT + 22) },
 	{ "pipe2", (X32_SYSCALL_BIT + 293) },
 	{ "pivot_root", (X32_SYSCALL_BIT + 155) },
@@ -261,6 +282,7 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "pkey_mprotect", (X32_SYSCALL_BIT + 329) },
 	{ "poll", (X32_SYSCALL_BIT + 7) },
 	{ "ppoll", (X32_SYSCALL_BIT + 271) },
+	{ "ppoll_time64", __PNR_ppoll_time64 },
 	{ "prctl", (X32_SYSCALL_BIT + 157) },
 	{ "pread64", (X32_SYSCALL_BIT + 17) },
 	{ "preadv", (X32_SYSCALL_BIT + 534) },
@@ -271,6 +293,7 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "prof", __PNR_prof },
 	{ "profil", __PNR_profil },
 	{ "pselect6", (X32_SYSCALL_BIT + 270) },
+	{ "pselect6_time64", __PNR_pselect6_time64 },
 	{ "ptrace", (X32_SYSCALL_BIT + 521) },
 	{ "putpmsg", (X32_SYSCALL_BIT + 182) },
 	{ "pwrite64", (X32_SYSCALL_BIT + 18) },
@@ -288,6 +311,7 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "recv", __PNR_recv },
 	{ "recvfrom", (X32_SYSCALL_BIT + 517) },
 	{ "recvmmsg", (X32_SYSCALL_BIT + 537) },
+	{ "recvmmsg_time64", __PNR_recvmmsg_time64 },
 	{ "recvmsg", (X32_SYSCALL_BIT + 519) },
 	{ "remap_file_pages", (X32_SYSCALL_BIT + 216) },
 	{ "removexattr", (X32_SYSCALL_BIT + 197) },
@@ -305,6 +329,7 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "rt_sigreturn", (X32_SYSCALL_BIT + 513) },
 	{ "rt_sigsuspend", (X32_SYSCALL_BIT + 130) },
 	{ "rt_sigtimedwait", (X32_SYSCALL_BIT + 523) },
+	{ "rt_sigtimedwait_time64", __PNR_rt_sigtimedwait_time64 },
 	{ "rt_tgsigqueueinfo", (X32_SYSCALL_BIT + 536) },
 	{ "rtas", __PNR_rtas },
 	{ "s390_guarded_storage", __PNR_s390_guarded_storage },
@@ -319,6 +344,7 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "sched_getparam", (X32_SYSCALL_BIT + 143) },
 	{ "sched_getscheduler", (X32_SYSCALL_BIT + 145) },
 	{ "sched_rr_get_interval", (X32_SYSCALL_BIT + 148) },
+	{ "sched_rr_get_interval_time64", __PNR_sched_rr_get_interval_time64 },
 	{ "sched_setaffinity", (X32_SYSCALL_BIT + 203) },
 	{ "sched_setattr", (X32_SYSCALL_BIT + 314) },
 	{ "sched_setparam", (X32_SYSCALL_BIT + 142) },
@@ -331,6 +357,7 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "semget", (X32_SYSCALL_BIT + 64) },
 	{ "semop", (X32_SYSCALL_BIT + 65) },
 	{ "semtimedop", (X32_SYSCALL_BIT + 220) },
+	{ "semtimedop_time64", __PNR_semtimedop_time64 },
 	{ "send", __PNR_send },
 	{ "sendfile", (X32_SYSCALL_BIT + 40) },
 	{ "sendfile64", __PNR_sendfile64 },
@@ -424,11 +451,15 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "timer_delete", (X32_SYSCALL_BIT + 226) },
 	{ "timer_getoverrun", (X32_SYSCALL_BIT + 225) },
 	{ "timer_gettime", (X32_SYSCALL_BIT + 224) },
+	{ "timer_gettime64", __PNR_timer_gettime64 },
 	{ "timer_settime", (X32_SYSCALL_BIT + 223) },
+	{ "timer_settime64", __PNR_timer_settime64 },
 	{ "timerfd", __PNR_timerfd },
 	{ "timerfd_create", (X32_SYSCALL_BIT + 283) },
 	{ "timerfd_gettime", (X32_SYSCALL_BIT + 287) },
+	{ "timerfd_gettime64", __PNR_timerfd_gettime64 },
 	{ "timerfd_settime", (X32_SYSCALL_BIT + 286) },
+	{ "timerfd_settime64", __PNR_timerfd_settime64 },
 	{ "times", (X32_SYSCALL_BIT + 100) },
 	{ "tkill", (X32_SYSCALL_BIT + 200) },
 	{ "truncate", (X32_SYSCALL_BIT + 76) },
@@ -450,6 +481,7 @@ const struct arch_syscall_def x32_syscall_table[] = { \
 	{ "ustat", (X32_SYSCALL_BIT + 136) },
 	{ "utime", (X32_SYSCALL_BIT + 132) },
 	{ "utimensat", (X32_SYSCALL_BIT + 280) },
+	{ "utimensat_time64", __PNR_utimensat_time64 },
 	{ "utimes", (X32_SYSCALL_BIT + 235) },
 	{ "vfork", (X32_SYSCALL_BIT + 58) },
 	{ "vhangup", (X32_SYSCALL_BIT + 153) },
