@@ -26,7 +26,7 @@
 #include "arch.h"
 #include "arch-x86_64.h"
 
-/* NOTE: based on Linux 4.15-rc7 */
+/* NOTE: based on Linux v5.4-rc4 */
 const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "_llseek", __PNR__llseek },
 	{ "_newselect", __PNR__newselect },
@@ -58,11 +58,17 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "chown32", __PNR_chown32 },
 	{ "chroot", 161 },
 	{ "clock_adjtime", 305 },
+	{ "clock_adjtime64", __PNR_clock_adjtime64 },
 	{ "clock_getres", 229 },
+	{ "clock_getres_time64", __PNR_clock_getres_time64 },
 	{ "clock_gettime", 228 },
+	{ "clock_gettime64", __PNR_clock_gettime64 },
 	{ "clock_nanosleep", 230 },
+	{ "clock_nanosleep_time64", __PNR_clock_nanosleep_time64 },
 	{ "clock_settime", 227 },
+	{ "clock_settime64", __PNR_clock_settime64 },
 	{ "clone", 56 },
+	{ "clone3", 435 },
 	{ "close", 3 },
 	{ "connect", 42 },
 	{ "copy_file_range", 326 },
@@ -106,7 +112,11 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "flock", 73 },
 	{ "fork", 57 },
 	{ "fremovexattr", 199 },
+	{ "fsconfig", 431 },
 	{ "fsetxattr", 190 },
+	{ "fsmount", 432 },
+	{ "fsopen", 430 },
+	{ "fspick", 433 },
 	{ "fstat", 5 },
 	{ "fstat64", __PNR_fstat64 },
 	{ "fstatat64", __PNR_fstatat64 },
@@ -117,6 +127,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "ftruncate", 77 },
 	{ "ftruncate64", __PNR_ftruncate64 },
 	{ "futex", 202 },
+	{ "futex_time64", __PNR_futex_time64 },
 	{ "futimesat", 261 },
 	{ "get_kernel_syms", 177 },
 	{ "get_mempolicy", 239 },
@@ -169,8 +180,12 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "io_destroy", 207 },
 	{ "io_getevents", 208 },
 	{ "io_pgetevents", 333 },
+	{ "io_pgetevents_time64", __PNR_io_pgetevents_time64 },
 	{ "io_setup", 206 },
 	{ "io_submit", 209 },
+	{ "io_uring_setup", 425 },
+	{ "io_uring_enter", 426 },
+	{ "io_uring_register", 427 },
 	{ "ioctl", 16 },
 	{ "ioperm", 173 },
 	{ "iopl", 172 },
@@ -214,6 +229,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "mmap2", __PNR_mmap2 },
 	{ "modify_ldt", 154 },
 	{ "mount", 165 },
+	{ "move_mount", 429 },
 	{ "move_pages", 279 },
 	{ "mprotect", 10 },
 	{ "mpx", __PNR_mpx },
@@ -221,7 +237,9 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "mq_notify", 244 },
 	{ "mq_open", 240 },
 	{ "mq_timedreceive", 243 },
+	{ "mq_timedreceive_time64", __PNR_mq_timedreceive_time64 },
 	{ "mq_timedsend", 242 },
+	{ "mq_timedsend_time64", __PNR_mq_timedsend_time64 },
 	{ "mq_unlink", 241 },
 	{ "mremap", 25 },
 	{ "msgctl", 71 },
@@ -246,6 +264,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "oldwait4", __PNR_oldwait4 },
 	{ "open", 2 },
 	{ "open_by_handle_at", 304 },
+	{ "open_tree", 428 },
 	{ "openat", 257 },
 	{ "pause", 34 },
 	{ "pciconfig_iobase", __PNR_pciconfig_iobase },
@@ -253,6 +272,8 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "pciconfig_write", __PNR_pciconfig_write },
 	{ "perf_event_open", 298 },
 	{ "personality", 135 },
+	{ "pidfd_open", 434 },
+	{ "pidfd_send_signal", 424 },
 	{ "pipe", 22 },
 	{ "pipe2", 293 },
 	{ "pivot_root", 155 },
@@ -261,6 +282,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "pkey_mprotect", 329 },
 	{ "poll", 7 },
 	{ "ppoll", 271 },
+	{ "ppoll_time64", __PNR_ppoll_time64 },
 	{ "prctl", 157 },
 	{ "pread64", 17 },
 	{ "preadv", 295 },
@@ -271,6 +293,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "prof", __PNR_prof },
 	{ "profil", __PNR_profil },
 	{ "pselect6", 270 },
+	{ "pselect6_time64", __PNR_pselect6_time64 },
 	{ "ptrace", 101 },
 	{ "putpmsg", 182 },
 	{ "pwrite64", 18 },
@@ -288,6 +311,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "recv", __PNR_recv },
 	{ "recvfrom", 45 },
 	{ "recvmmsg", 299 },
+	{ "recvmmsg_time64", __PNR_recvmmsg_time64 },
 	{ "recvmsg", 47 },
 	{ "remap_file_pages", 216 },
 	{ "removexattr", 197 },
@@ -305,6 +329,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "rt_sigreturn", 15 },
 	{ "rt_sigsuspend", 130 },
 	{ "rt_sigtimedwait", 128 },
+	{ "rt_sigtimedwait_time64", __PNR_rt_sigtimedwait_time64 },
 	{ "rt_tgsigqueueinfo", 297 },
 	{ "rtas", __PNR_rtas },
 	{ "s390_guarded_storage", __PNR_s390_guarded_storage },
@@ -319,6 +344,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "sched_getparam", 143 },
 	{ "sched_getscheduler", 145 },
 	{ "sched_rr_get_interval", 148 },
+	{ "sched_rr_get_interval_time64", __PNR_sched_rr_get_interval_time64 },
 	{ "sched_setaffinity", 203 },
 	{ "sched_setattr", 314 },
 	{ "sched_setparam", 142 },
@@ -331,6 +357,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "semget", 64 },
 	{ "semop", 65 },
 	{ "semtimedop", 220 },
+	{ "semtimedop_time64", __PNR_semtimedop_time64 },
 	{ "send", __PNR_send },
 	{ "sendfile", 40 },
 	{ "sendfile64", __PNR_sendfile64 },
@@ -424,11 +451,15 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "timer_delete", 226 },
 	{ "timer_getoverrun", 225 },
 	{ "timer_gettime", 224 },
+	{ "timer_gettime64", __PNR_timer_gettime64 },
 	{ "timer_settime", 223 },
+	{ "timer_settime64", __PNR_timer_settime64 },
 	{ "timerfd", __PNR_timerfd },
 	{ "timerfd_create", 283 },
 	{ "timerfd_gettime", 287 },
+	{ "timerfd_gettime64", __PNR_timerfd_gettime64 },
 	{ "timerfd_settime", 286 },
+	{ "timerfd_settime64", __PNR_timerfd_settime64 },
 	{ "times", 100 },
 	{ "tkill", 200 },
 	{ "truncate", 76 },
@@ -450,6 +481,7 @@ const struct arch_syscall_def x86_64_syscall_table[] = { \
 	{ "ustat", 136 },
 	{ "utime", 132 },
 	{ "utimensat", 280 },
+	{ "utimensat_time64", __PNR_utimensat_time64 },
 	{ "utimes", 235 },
 	{ "vfork", 58 },
 	{ "vhangup", 153 },
