@@ -1,8 +1,8 @@
 /**
  * Enhanced Seccomp Filter DB
  *
- * Copyright (c) 2012 Red Hat <pmoore@redhat.com>
- * Author: Paul Moore <pmoore@redhat.com>
+ * Copyright (c) 2012,2016 Red Hat <pmoore@redhat.com>
+ * Author: Paul Moore <paul@paul-moore.com>
  */
 
 /*
@@ -33,24 +33,37 @@
 
 struct db_api_arg {
 	unsigned int arg;
-	unsigned int op;
+	enum scmp_compare op;
 	scmp_datum_t mask;
 	scmp_datum_t datum;
 
 	bool valid;
 };
 
+struct db_api_rule_list {
+	uint32_t action;
+	int syscall;
+	bool strict;
+	struct db_api_arg args[ARG_COUNT_MAX];
+
+	struct db_api_rule_list *prev, *next;
+};
+
 struct db_arg_chain_tree {
 	/* argument number (a0 = 0, a1 = 1, etc.) */
 	unsigned int arg;
+	/* true to indicate this is the high 32-bit word of a 64-bit value */
+	bool arg_h_flg;
 	/* argument bpf offset */
 	unsigned int arg_offset;
 
 	/* comparison operator */
 	enum scmp_compare op;
+	enum scmp_compare op_orig;
 	/* syscall argument value */
 	uint32_t mask;
 	uint32_t datum;
+	scmp_datum_t datum_full;
 
 	/* actions */
 	bool act_t_flg;
@@ -68,36 +81,6 @@ struct db_arg_chain_tree {
 	unsigned int refcnt;
 };
 #define ARG_MASK_MAX		((uint32_t)-1)
-#define db_chain_lt(x,y) \
-	(((x)->arg < (y)->arg) || \
-	 (((x)->arg == (y)->arg) && \
-	  (((x)->op < (y)->op) || (((x)->mask & (y)->mask) == (y)->mask))))
-#define db_chain_eq(x,y) \
-	(((x)->arg == (y)->arg) && \
-	 ((x)->op == (y)->op) && ((x)->datum == (y)->datum) && \
-	 ((x)->mask == (y)->mask))
-#define db_chain_gt(x,y) \
-	(((x)->arg > (y)->arg) || \
-	 (((x)->arg == (y)->arg) && \
-	  (((x)->op > (y)->op) || (((x)->mask & (y)->mask) != (y)->mask))))
-#define db_chain_action(x) \
-	(((x)->act_t_flg) || ((x)->act_f_flg))
-#define db_chain_zombie(x) \
-	((x)->nxt_t == NULL && !((x)->act_t_flg) && \
-	 (x)->nxt_f == NULL && !((x)->act_f_flg))
-#define db_chain_leaf(x) \
-	((x)->nxt_t == NULL && (x)->nxt_f == NULL)
-#define db_chain_eq_result(x,y) \
-	((((x)->nxt_t != NULL && (y)->nxt_t != NULL) || \
-	  ((x)->nxt_t == NULL && (y)->nxt_t == NULL)) && \
-	 (((x)->nxt_f != NULL && (y)->nxt_f != NULL) || \
-	  ((x)->nxt_f == NULL && (y)->nxt_f == NULL)) && \
-	 ((x)->act_t_flg == (y)->act_t_flg) && \
-	 ((x)->act_f_flg == (y)->act_f_flg) && \
-	 (((x)->act_t_flg && (x)->act_t == (y)->act_t) || \
-	  (!((x)->act_t_flg))) && \
-	 (((x)->act_f_flg && (x)->act_f == (y)->act_f) || \
-	  (!((x)->act_f_flg))))
 
 struct db_sys_list {
 	/* native syscall number */
@@ -129,6 +112,10 @@ struct db_filter_attr {
 	uint32_t nnp_enable;
 	/* SECCOMP_FILTER_FLAG_TSYNC related attributes */
 	uint32_t tsync_enable;
+	/* allow rules with a -1 syscall value */
+	uint32_t api_tskip;
+	/* SECCOMP_FILTER_FLAG_LOG related attributes */
+	uint32_t log_enable;
 };
 
 struct db_filter {
@@ -137,6 +124,17 @@ struct db_filter {
 
 	/* syscall filters, kept as a sorted single-linked list */
 	struct db_sys_list *syscalls;
+
+	/* list of rules used to build the filters, kept in order */
+	struct db_api_rule_list *rules;
+};
+
+struct db_filter_snap {
+	/* individual filters */
+	struct db_filter **filters;
+	unsigned int filter_cnt;
+
+	struct db_filter_snap *next;
 };
 
 struct db_filter_col {
@@ -150,6 +148,9 @@ struct db_filter_col {
 	int endian;
 	struct db_filter **filters;
 	unsigned int filter_cnt;
+
+	/* transaction snapshots */
+	struct db_filter_snap *snapshots;
 };
 
 /**
@@ -166,8 +167,10 @@ struct db_filter_col {
 
 int db_action_valid(uint32_t action);
 
+struct db_api_rule_list *db_rule_dup(const struct db_api_rule_list *src);
+
 struct db_filter_col *db_col_init(uint32_t def_action);
-void db_col_reset(struct db_filter_col *col, uint32_t def_action);
+int db_col_reset(struct db_filter_col *col, uint32_t def_action);
 void db_col_release(struct db_filter_col *col);
 
 int db_col_valid(struct db_filter_col *col);
@@ -181,17 +184,21 @@ int db_col_attr_get(const struct db_filter_col *col,
 int db_col_attr_set(struct db_filter_col *col,
 		    enum scmp_filter_attr attr, uint32_t value);
 
+int db_col_db_new(struct db_filter_col *col, const struct arch_def *arch);
 int db_col_db_add(struct db_filter_col *col, struct db_filter *db);
 int db_col_db_remove(struct db_filter_col *col, uint32_t arch_token);
 
-struct db_filter *db_init(const struct arch_def *arch);
-void db_reset(struct db_filter *db);
-void db_release(struct db_filter *db);
+int db_col_rule_add(struct db_filter_col *col,
+		    bool strict, uint32_t action, int syscall,
+		    unsigned int arg_cnt, const struct scmp_arg_cmp *arg_array);
 
-int db_syscall_priority(struct db_filter *db,
-			unsigned int syscall, uint8_t priority);
+int db_col_syscall_priority(struct db_filter_col *col,
+			    int syscall, uint8_t priority);
 
-int db_rule_add(struct db_filter *db, uint32_t action, unsigned int syscall,
-		struct db_api_arg *chain);
+int db_col_transaction_start(struct db_filter_col *col);
+void db_col_transaction_abort(struct db_filter_col *col);
+void db_col_transaction_commit(struct db_filter_col *col);
+
+int db_rule_add(struct db_filter *db, const struct db_api_rule_list *rule);
 
 #endif
